/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.reactivex.ext.cluster.infinispan;

import java.util.Map;
import io.reactivex.Observable;
import io.reactivex.Flowable;
import io.reactivex.Single;
import io.reactivex.Completable;
import io.reactivex.Maybe;
import io.vertx.ext.healthchecks.Status;
import io.vertx.reactivex.core.Vertx;
import io.vertx.core.Handler;
import io.vertx.reactivex.core.Future;

/**
 * A helper to create Vert.x cluster {@link io.vertx.reactivex.ext.healthchecks.HealthChecks} procedures.
 *
 * <p/>
 * NOTE: This class has been automatically generated from the {@link io.vertx.ext.cluster.infinispan.ClusterHealthCheck original} non RX-ified interface using Vert.x codegen.
 */

@io.vertx.lang.reactivex.RxGen(io.vertx.ext.cluster.infinispan.ClusterHealthCheck.class)
public class ClusterHealthCheck {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterHealthCheck that = (ClusterHealthCheck) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final io.vertx.lang.reactivex.TypeArg<ClusterHealthCheck> __TYPE_ARG = new io.vertx.lang.reactivex.TypeArg<>(
    obj -> new ClusterHealthCheck((io.vertx.ext.cluster.infinispan.ClusterHealthCheck) obj),
    ClusterHealthCheck::getDelegate
  );

  private final io.vertx.ext.cluster.infinispan.ClusterHealthCheck delegate;
  
  public ClusterHealthCheck(io.vertx.ext.cluster.infinispan.ClusterHealthCheck delegate) {
    this.delegate = delegate;
  }

  public io.vertx.ext.cluster.infinispan.ClusterHealthCheck getDelegate() {
    return delegate;
  }

  /**
   * Like {@link io.vertx.reactivex.ext.cluster.infinispan.ClusterHealthCheck#createProcedure} with <code>details</code> set to <code>true</code>.
   * @param vertx 
   * @return 
   */
  public static Handler<Future<Status>> createProcedure(Vertx vertx) { 
    Handler<Future<Status>> ret = new Handler<Future<Status>>() {
      public void handle(Future<Status> event) {
          io.vertx.ext.cluster.infinispan.ClusterHealthCheck.createProcedure(vertx.getDelegate()).handle(event.getDelegate());
      }
    };
    return ret;
  }

  /**
   * Creates a ready-to-use Vert.x cluster {@link io.vertx.reactivex.ext.healthchecks.HealthChecks} procedure.
   * @param vertx the instance of Vert.x, must not be <code>null</code>
   * @param detailed when set to <code>true</code>,  will be set with cluster health details
   * @return a Vert.x cluster {@link io.vertx.reactivex.ext.healthchecks.HealthChecks} procedure
   */
  public static Handler<Future<Status>> createProcedure(Vertx vertx, boolean detailed) { 
    Handler<Future<Status>> ret = new Handler<Future<Status>>() {
      public void handle(Future<Status> event) {
          io.vertx.ext.cluster.infinispan.ClusterHealthCheck.createProcedure(vertx.getDelegate(), detailed).handle(event.getDelegate());
      }
    };
    return ret;
  }


  public static  ClusterHealthCheck newInstance(io.vertx.ext.cluster.infinispan.ClusterHealthCheck arg) {
    return arg != null ? new ClusterHealthCheck(arg) : null;
  }
}
